@@ -26,8 +26,9 @@ def runGame(Ais,gameName):
     try:
         gameResult = game.runGame(False)
         result.update(gameResult)
-    except:
+    except Exception as err:
         result["error"] = "Game Run"
+        result["errMessage"] = err
         result["replayStates"] = game.replayStates
         return result
     #gameResult = game.runGame(False)
