@@ -2,37 +2,42 @@ import requests
 import json
 
 
-
-
-
-
 class StockMarket:
     """This implements a game of a Stock Market Simulator"""
-    def __init__(self, state=None, players=None, APIKey=None):
+    def __init__(self, state=None, players=None, APIKey=None, StockData=None):
         #Game Constants
         self.startValue = 10**6
         self.interval = 15
         self.APIKey = APIKey
+        if APIKey is None and StockData is None:
+            with open("SM_SampleData.txt") as f:
+                StockData = json.load(f)
 
         if players is None:
             self.players = []
+        else:
+            self.players = players
 
         if state:
             self.state = state
+            for p in self.players:
+                if p.id not in self.state["portfolios"]:#new players
+                    self.state["portfolios"][p.id] = {
+                        "cash":self.startValue,
+                        "stocks":{},
+                        "trades":[]
+                    }
         else:
             self.state = {
                 "endDate": "endDate",
-                "symbols": ["FB"],#,"AMZN","AAPL","NFLX","GOOGL"],
+                "symbols": ["FB","AMZN","AAPL","NFLX","GOOGL"],
                 "data":{},
                 "players": players,
                 "portfolios":{}
             }
 
             for s in self.state["symbols"]:
-                self.state["data"][s] = {
-                    "all":{},
-                    "last":{}
-                }
+                self.state["data"][s] = []
 
             for p in self.players:
                 self.state["portfolios"][p.id] = {
@@ -41,6 +46,16 @@ class StockMarket:
                     "trades":[]
                 }
 
+        self.cached = {}
+        if StockData is not None:
+            for s, data in StockData.items():
+                self.cached[s] = True
+                self.state["data"][s] = data
+                #get last
+                #last = sorted(list(data),reverse=True)[0]
+                #self.state["data"][s]["last"] = data[last]
+
+
 
 
     def print(self):
@@ -53,12 +68,10 @@ class StockMarket:
 
     def gatherStockData(self):
         for sym in self.state["symbols"]:
-            data, last = self.getStockData(sym, str(self.interval)+"min")
-            for date, value in data.items():
-                self.state["data"][sym]["all"][date] = {}
-                for key, val in value.items():
-                    self.state["data"][sym]["all"][date][key[3:]] = float(val)
-            self.state["data"][sym]["last"] = self.state["data"][sym]["all"][last]
+            if sym in self.cached:
+                continue
+            prices = self.getStockData(sym, str(self.interval)+"min")
+            self.state["data"][sym] = prices + self.state["data"][sym]
             #print(self.state["data"][sym])
 
     def getStockData(self, symbol, interval):
@@ -72,8 +85,11 @@ class StockMarket:
         r = requests.get("https://www.alphavantage.co/query", payload)
         if r.status_code == 200:
             data = json.loads(r.content.decode())
-            last = data["Meta Data"]["3. Last Refreshed"]
-            return data["Time Series (" + interval + ")"], last
+            #last = data["Meta Data"]["3. Last Refreshed"]
+            prices = []
+            for date, d in data["Time Series (" + interval + ")"].items():
+                prices.append(float(d['4. close']))
+            return prices
         else:
             print("An error occured:", r.status_code, r.content)
 
@@ -84,7 +100,7 @@ class StockMarket:
     def validateTrade(self, trade, portfolio):
         if trade["symbol"] in self.state["symbols"]:
             if trade["action"] == "buy":
-                cost = trade["quantity"] * self.state["data"][trade["symbol"]]["last"]["close"]
+                cost = trade["quantity"] * self.state["data"][trade["symbol"]][0]
                 if cost < portfolio['cash']:
                     return True
             elif trade["action"] == "sell":
@@ -93,10 +109,10 @@ class StockMarket:
         return False
 
     def makeTrade(self, trade, portfolio, aid):#Assumes trade was validated
-        cost = trade["quantity"] * self.state["data"][trade["symbol"]]["last"]["close"]
+        cost = trade["quantity"] * self.state["data"][trade["symbol"]][0]
         if trade["action"] == "buy":
             self.state['portfolios'][aid]['cash'] -= cost
-            if trade["symbol"] in portfolio:
+            if trade["symbol"] in portfolio['stocks']:
                 self.state['portfolios'][aid]['stocks'][trade["symbol"]] += trade["quantity"]
             else:
                 self.state['portfolios'][aid]['stocks'][trade["symbol"]] = trade["quantity"]
@@ -109,7 +125,7 @@ class StockMarket:
             portfolio = self.state['portfolios'][move['aid']]
             if self.validateTrade(trade, portfolio):
                 self.makeTrade(trade,portfolio,move['aid'])
-
+                self.state['portfolios'][move['aid']]['trades'].append(trade)
 
     def postMove(self):
         pass
@@ -119,8 +135,19 @@ class StockMarket:
         #print(self.state["players"][winner])
         self.state["Winner"] = winner
 
-import AIArena
+    def exportData(self):
+        data = {}
+        for s in self.state["symbols"]:
+            data[s] = self.state["data"][s]
+        return data
 
+    def exportValue(self, id):
+        val = self.state['portfolios'][id]['cash']
+        for ticker, quant in self.state['portfolios'][id]['stocks'].items():
+            val += quant * self.state["data"][ticker][0]
+        return val
+
+import AIArena
 
 
 if __name__ == "__main__":
@@ -129,12 +156,10 @@ if __name__ == "__main__":
             super().__init__(name, "StockMarket")
 
     ai1 = lilStockBuddy("lilStockBuddy")
-    #sm = StockMarket(players=[ai1],APIKey="0C0G6TQ153Q7Y67L")
-    sm = StockMarket(players=[ai1], APIKey="0C0G6TQ153Q7Y67L")
+    sm = StockMarket(players=[ai1])
     sm.gatherStockData()
+    print(json.dumps(sm.exportData()))
 
-
-    """
     trades = [
         {'action':"buy",'symbol':"FB",'quantity':100}
     ]
@@ -149,11 +174,11 @@ if __name__ == "__main__":
     sm.print()
 
     trades = [
-        {'action': "sell", 'symbol': "FB", 'quantity': 100},
-        {'action': "buy", 'symbol': "FB", 'quantity': 1000},
-        {'action': "sell", 'symbol': "FB", 'quantity': 100}
+        {'action': "buy", 'symbol': "FB", 'quantity': 100}
     ]
 
+    sm = StockMarket(players=[ai1], state=sm.state)
+
     move = {
         'aid': ai1.id,
         'trades': trades
@@ -161,4 +186,4 @@ if __name__ == "__main__":
 
     sm.makeMove(move)
     sm.print()
-    """
\ No newline at end of file
+    print(sm.exportValue(ai1.id))
